@@ -5,13 +5,11 @@
 
 #include "weighted_choice.h"
 
+// gets the distances between all the pairs of elements from a list
+//
+// @param sites array of positions
+// @return vector of paired positions
 void _get_distances(int sites[], int & len, int distances[]) {
-    /**
-        gets the distances between all the pairs of elements from a list
-        
-        @sites array of positions
-        @return vector of paired positions
-    */
     // get all non-repeating combinations of the sites
     int idx = 0;
     for (int i=0; i < len; i++) {
@@ -40,14 +38,11 @@ void _get_distances(std::vector<int> sites, std::vector<int> & distances) {
     }
 }
 
+// check if any value in an vector is zero
+//
+// @param distances vector of values
+// @return true/false for containing zero
 bool _has_zero(int distances[], int & len) {
-    /**
-        @check if any value in an vector is zero
-        
-        @distances vector of values
-        
-        @return true/false for containing zero
-    */
     return std::find(distances, distances + len, 0) != distances + len;
 }
 
@@ -57,35 +52,28 @@ bool _has_zero(std::vector<int> distances) {
     return _has_zero(dist, len);
 }
 
+// gets the geometric mean of a vector of distances
+//
+// @param sites vector of distances
+// @return geometric mean
 double _geomean(int distances[], int & len) {
-    /**
-        gets the geometric mean of a vector of distances
-        
-        @sites vector of distances
-        @return geometric mean
-    */
     bool zero_val = _has_zero(distances, len);
-    
     double total = 0;
     // if some values are zero, adjust the values upwards, then add the log10
     // value, otherwise add the uncorrected log10 value
     if (zero_val) {
         for (int i=0; i < len; i++) {
-            total += log10(distances[i] + 1);
+            total += log(distances[i] + 1);
         }
     } else {
         for (int i=0; i < len; i++) {
-            total += log10(distances[i]);
+            total += log(distances[i]);
         }
     }
-    
-    // calculate the mean value
-    double mean = total/len;
-    mean = std::pow(10, mean);
-    
+
+    double mean = exp(total / len);
     // adjust mean back to where it should be if we had a zero value
     if (zero_val) { mean -= 1; }
-    
     return mean;
 }
 
@@ -95,16 +83,14 @@ double _geomean(std::vector<int> distances) {
     return _geomean(dist, len);
 }
 
+// simulates de novos weighted by mutation rate
+//
+// @param choices Chooser object, to sample sites
+// @param iteration number of iterations to run
+// @param de_novo_count number of de novos to simulate per iteration
+// @return a list of mean distances for each iteration
 std::vector<double> _simulate_distribution(Chooser & choices, int iterations,
     int de_novo_count) {
-    /**
-        simulates de novos weighted by mutation rate
-        
-        @choices Chooser object, to sample sites
-        @iteration number of iterations to run
-        @de_novo_count number of de novos to simulate per iteration
-        @return a list of mean distances for each iteration
-    */
     
     // use a vector to return the mean distances, easier to call from python
     std::vector<double> mean_distances(iterations);
@@ -116,7 +102,7 @@ std::vector<double> _simulate_distribution(Chooser & choices, int iterations,
     for (int n=0; n < iterations; n++) {
         // randomly select de novo sites for the iteration
         for (int i=0; i < de_novo_count; i++) {
-            positions[i] = choices.choice().pos;
+            positions[i] = choices.choice_pos_only();
         }
         
         // convert the positions into distances between all pairs, and get the
@@ -133,23 +119,20 @@ std::vector<double> _simulate_distribution(Chooser & choices, int iterations,
     return mean_distances;
 }
 
+// halt permutations if the P value could never be significant.
+//
+// assess whether the P-value could never fall below 0.1, and cut out after a
+// smaller number of iterations, in order to minimise run time. Figure out the
+// lower bound of the confidence interval for the current simulated P value.
+//
+// @param p_val current simulated P value
+// @param iterations iterations run in order to obtain the simulated P value
+// @param z standard normal deviate (eg 1.96 for 95% CI)
+// @param alpha value above which to cease permuting
+// @return True/False for whether to halt the permuations
 bool _halt_permutation(double p_val, int iterations, double z, double alpha) {
-    /**
-        halt permutations if the P value could never be significant
-    
-        assess whether the P-value could never fall below 0.1, and cut
-        out after a smaller number of iterations, in order to minimise
-        run time. Figure out the lower bound of the confidence interval
-        for the current simulated P value.
-        TODO: figure out whether this is legit, perhaps a Sequential
-        TODO: Probability Ratio Test (SPRT) would be more appropriate.
-        
-        @p_val current simulated P value
-        @iterations iterations run in order to obtain the simulated P value
-        @z standard normal deviate (eg 1.96 for 95% CI)
-        @alpha value above which to cease permuting
-        @return True/False for whether to halt the permuations
-    */
+    // @todo figure out whether this is legit, perhaps a Sequential
+    // @todo Probability Ratio Test (SPRT) would be more appropriate.
     double delta = (z * sqrt((p_val * (1 - p_val))))/iterations;
     double lower_bound = p_val - delta;
     
@@ -158,17 +141,15 @@ bool _halt_permutation(double p_val, int iterations, double z, double alpha) {
     return lower_bound > alpha;
 }
 
+// simulates de novos weighted by mutation rate
+//
+// @param choices Chooser object, to sample sites
+// @param iteration number of iterations to run
+// @param de_novo_count number of de novos to simulate per iteration
+// @param observed_value mean distance observed in the real de novo events
+// @return a list of mean distances for each iteration
 double _analyse_de_novos(Chooser & choices, int iterations, int de_novo_count,
     double observed_value) {
-    /**
-        simulates de novos weighted by mutation rate
-        
-        @choices Chooser object, to sample sites
-        @iteration number of iterations to run
-        @de_novo_count number of de novos to simulate per iteration
-        @observed_value mean distance observed in the real de novo events
-        @return a list of mean distances for each iteration
-    */
     
     double minimum_prob = 1.0/(1.0 + static_cast<double>(iterations));
     double sim_prob = minimum_prob;
