@@ -25,9 +25,9 @@ Region _get_gene_range(Tx & tx) {
 // @param intra_codon position within the codon to be altered (0-based)
 // @returns single character amino acid code translated from the altered
 //     codon.
-std::string _get_mutated_aa(Tx & tx, std::string base, std::string codon, int intra_codon) {
+std::string _get_mutated_aa(Tx & tx, char base, std::string codon, int intra_codon) {
     // figure out what the mutated codon is
-    codon.replace(intra_codon, 1, base);
+    codon[intra_codon] = base;
     return tx.translate(codon);
 }
 
@@ -110,7 +110,7 @@ void SitesChecks::check_position(int bp) {
         bp > std::max(_tx.get_cds_start(), _tx.get_cds_end())) {
         return ;
     }
-    
+
     std::string seq = _tx.get_centered_sequence(bp, kmer_length);
     boundary_dist = _tx.get_boundary_distance(bp);
     
@@ -118,7 +118,7 @@ void SitesChecks::check_position(int bp) {
     if (_tx.get_strand() != fwd) {
         seq = _tx.reverse_complement(seq);
     }
-    
+
     Codon codon;
     try {
         codon = _tx.get_codon_info(bp);
@@ -129,30 +129,31 @@ void SitesChecks::check_position(int bp) {
     std::string initial_aa = codon.initial_aa;
     int cds_pos = codon.cds_pos;
     int offset = codon.offset;
-    
+
     // drop the initial base, since we want to mutate to other bases
-    std::vector<std::string> alts(bases);
-    alts.erase(std::find(alts.begin(), alts.end(), seq.substr(mid_pos, 1)));
+    std::vector<char> alts(bases);
+    char ref = seq[mid_pos];
+    auto matches = std::find(alts.begin(), alts.end(), ref);
+    if (matches != std::end(alts)) {
+        alts.erase(matches);
+    }
     
     std::string mutated_aa;
-    std::string alt_seq;
-    std::string ref;
+    std::string alt_seq = seq;
     std::string category;
     for (auto &alt : alts) {
         mutated_aa = initial_aa;
-        alt_seq = seq.substr(0, mid_pos) + alt +
-            seq.substr(mid_pos + 1, kmer_length - mid_pos);
+        alt_seq[mid_pos] = alt;
         
         double rate = mut_dict[seq][alt_seq];
-        if ( initial_aa != "" ) {
+        if ( initial_aa.size() != 0 ) {
             mutated_aa = _get_mutated_aa(_tx, alt, codon.codon_seq, codon.intra_codon);
         }
-        
+
         category = check_consequence(initial_aa, mutated_aa, bp);
         
         // figure out what the ref and alt alleles are, with respect to
         // the + strand.
-        ref = seq.substr(mid_pos, 1);
         if (_tx.get_strand() != fwd) {
             ref = transdict[ref];
             alt = transdict[alt];
