@@ -11,7 +11,8 @@
 
 std::unordered_map<char, char> transdict = {
     {'a', 't'}, {'c', 'g'}, {'g', 'c'}, {'t', 'a'}, {'u', 'a'},
-    {'A', 'T'}, {'C', 'G'}, {'G', 'C'}, {'T', 'A'}, {'U', 'A'}};
+    {'A', 'T'}, {'C', 'G'}, {'G', 'C'}, {'T', 'A'}, {'U', 'A'},
+    {'N', 'N'}};
 
 std::unordered_map<std::string, std::string> aa_code = {
     {"AAA", "K"}, {"AAC", "N"}, {"AAG", "K"}, {"AAT", "N"},
@@ -494,9 +495,12 @@ void Tx::_fix_cds_length() {
 std::string Tx::reverse_complement(std::string seq) {
     std::reverse(seq.begin(), seq.end());
     std::string complement;
+    complement.resize(seq.size());
     
+    int i = 0;
     for (auto &base : seq) {
-        complement += transdict[base];
+        complement[i] = transdict[base];
+        i += 1;
     }
     
     return complement;
