@@ -41,28 +41,6 @@ class Tx {
     int gdna_offset=0;
     std::string genomic_sequence = "";
     
-    std::unordered_map<char, char> transdict = {
-        {'a', 't'}, {'c', 'g'}, {'g', 'c'}, {'t', 'a'}, {'u', 'a'},
-        {'A', 'T'}, {'C', 'G'}, {'G', 'C'}, {'T', 'A'}, {'U', 'A'}};
-    
-    std::unordered_map<std::string, std::string> aa_code = {
-        {"AAA", "K"}, {"AAC", "N"}, {"AAG", "K"}, {"AAT", "N"},
-        {"ACA", "T"}, {"ACC", "T"}, {"ACG", "T"}, {"ACT", "T"},
-        {"AGA", "R"}, {"AGC", "S"}, {"AGG", "R"}, {"AGT", "S"},
-        {"ATA", "I"}, {"ATC", "I"}, {"ATG", "M"}, {"ATT", "I"},
-        {"CAA", "Q"}, {"CAC", "H"}, {"CAG", "Q"}, {"CAT", "H"},
-        {"CCA", "P"}, {"CCC", "P"}, {"CCG", "P"}, {"CCT", "P"},
-        {"CGA", "R"}, {"CGC", "R"}, {"CGG", "R"}, {"CGT", "R"},
-        {"CTA", "L"}, {"CTC", "L"}, {"CTG", "L"}, {"CTT", "L"},
-        {"GAA", "E"}, {"GAC", "D"}, {"GAG", "E"}, {"GAT", "D"},
-        {"GCA", "A"}, {"GCC", "A"}, {"GCG", "A"}, {"GCT", "A"},
-        {"GGA", "G"}, {"GGC", "G"}, {"GGG", "G"}, {"GGT", "G"},
-        {"GTA", "V"}, {"GTC", "V"}, {"GTG", "V"}, {"GTT", "V"},
-        {"TAA", "*"}, {"TAC", "Y"}, {"TAG", "*"}, {"TAT", "Y"},
-        {"TCA", "S"}, {"TCC", "S"}, {"TCG", "S"}, {"TCT", "S"},
-        {"TGA", "*"}, {"TGC", "C"}, {"TGG", "W"}, {"TGT", "C"},
-        {"TTA", "L"}, {"TTC", "F"}, {"TTG", "L"}, {"TTT", "F"}};
-    
     std::unordered_map<int, int> exon_to_cds;
     void _cache_exon_cds_positions();
     
@@ -76,6 +54,7 @@ class Tx {
  public:
     Tx(std::string transcript_id, std::string chromosome, int start_pos,
         int end_pos, char strand);
+    Tx() {};
     void set_exons(std::vector<std::vector<int>> exon_ranges,
         std::vector<std::vector<int>> cds_ranges);
     void set_cds(std::vector<std::vector<int>> cds_ranges);
